<?php
/*
Plugin Name: Total: Vertical Header Widget Area
Description: Registers a widget area to be used with the Vertical Header style.
Version: 1.2
Author: Aj Clarke
Author URI: http://www.wpexplorer.com
License: GPLv2
*/

// Start Class
class Total_Vertical_Header_Widget_Area {

	/**
	 * Main constructor
	 *
	 * @since 1.0.0
	 */
	public function __construct() {
		add_action( 'widgets_init', array( $this, 'register_widget' ) );
		add_action( 'wpex_hook_header_inner', array( $this, 'display_widgets' ), 999 );
	}

	/**
	 * Registers the new widget area
	 *
	 * @since 1.0.0
	 */
	public function register_widget() {
		$sidebar_headings = wp_strip_all_tags( get_theme_mod( 'sidebar_headings', 'div' ) );
		register_sidebar( array(
			'name'          => esc_html__( 'Vertical Header Sidebar', 'total' ),
			'id'            => 'vertical_header_sidebar',
			'before_widget' => '<div class="sidebar-box %2$s clr">',
			'after_widget'  => '</div>',
			'before_title'  => '<' . $sidebar_headings . ' class="widget-title">',
			'after_title'   => '</' . $sidebar_headings . '>',
		) );
	}

	/**
	 * Displays widget area
	 *
	 * @since 1.0.0
	 */
	public function display_widgets() {
		if ( function_exists( 'wpex_header_style' )
			&& 'six' == wpex_header_style()
			&& is_active_sidebar( 'vertical_header_sidebar' )
		) {
			echo '<div class="vertical-header-widgets hide-at-mm-breakpoint clr" style="padding:30px;">';
				dynamic_sidebar( 'vertical_header_sidebar' );
			echo '</div>';
		}
	}

}
new Total_Vertical_Header_Widget_Area;